`smore.swagger`: Generate Swagger definitions from marshmallow `Schemas` and webargs `Args`
===========================================================================================

.. automodule:: smore.swagger
    :inherited-members:
